@@ -85,6 +85,11 @@ def clear_a_path_for(path, overwrite=False, extension=".old"):
             else:
                 move_out_of_the_way(each_path, extension)
     ensure_is_folder(os.path.dirname(original_path))
+    if overwrite:
+        remove(path)
+    else:
+        move_out_of_the_way(path, extension)
+    
     return original_path
 
 def copy(item, *, to, new_name="", force=True):
@@ -206,7 +211,7 @@ def basename(path):
     return os.path.basename(path)
 
 def name(path):
-    filename, file_extension = os.path.splitext(path)
+    filename, file_extension = os.path.splitext(os.path.basename(path))
     return filename
 
 def extname(path):
